#SBATCH --partition xeon24
#SBATCH --ntasks 24
#SBATCH --time 2:15:0

import numpy as np
from ase.io import read, write
from gpaw import GPAW, PoissonSolver, FermiDirac, Davidson, Mixer, PW
from gpaw.utilities import h2gpts
from gpaw.mpi import world
from ase.cluster.icosahedron import Icosahedron
from gpaw.utilities.timing import ParallelTimer

atoms = Icosahedron('Au', 3)
atoms.center(vacuum=5.0)

calc = GPAW(mode=PW(800.0),
            timer=ParallelTimer(),
            #eigensolver=Davidson(2),
            occupations=FermiDirac(0.01),
            nbands='110%',
            txt='gpaw.txt',
            parallel=dict(augment_grids=True),
            xc='PBE')

def stopcalc():
    calc.scf.converged = True
calc.attach(stopcalc, 12)

atoms.calc = calc
atoms.get_forces()
